import { test, expect } from '@playwright/test';

test('UI test - navigate and check heading', async ({ page }) => {
  await page.goto('https://playwright.dev');
  const heading = await page.locator('h1');
  await expect(heading).toHaveText(/Playwright/);
});