import { test as base, expect } from "@playwright/test";

type Fixtures = {
  authToken: string;
};

export const test = base.extend<Fixtures>({
  authToken: async ({}, use) => {
    await use(process.env.AUTH_TOKEN ?? "fake-token");
  },
});

export { expect };